@@ -160,10 +160,9 @@ convert_to_markdown <- function(article_dir, kable_tab = TRUE, autonumber_eq = F
     if (kable_tab) {
         pandoc_opt <- c(pandoc_opt,
                         "--lua-filter", table_code_chunk,
-                        "--lua-filter", stat_filter,
-                        "--lua-filter", bookdown_ref_filter)
+                        "--lua-filter", stat_filter)
     }
-
+    pandoc_opt <- c(pandoc_opt,"--lua-filter", bookdown_ref_filter)
     output_format <- "markdown-simple_tables-pipe_tables-fenced_code_attributes"
     # This will generate a markdown file with YAML headers.
     if (!pandoc_version_check()) {
@@ -349,11 +348,12 @@ generate_rmd <- function(article_dir, web_dir= TRUE, interactive_mode = FALSE) {
         preview = "preview.png",
         bibliography = metadata$bibliography,
         CTV = article_metadata$CTV_rev,
+        legacy_pdf = TRUE,
+        legacy_converted = TRUE,
         output = list(
             `rjtools::rjournal_web_article` = list(
                 self_contained = TRUE,
                 toc = FALSE,
-                legacy_pdf = TRUE,
                 mathjax = "https://cdn.jsdelivr.net/npm/mathjax@3/es5/tex-chtml-full.js",
                 md_extension = "-tex_math_single_backslash"
             )
