@@ -16,11 +16,7 @@ stream_editor <- function(raw_lines, pattern, target, replacement) {
     break_points <- which(grepl(pattern, raw_lines))
     #check for length of break_points to avoid no matches
     if (!identical(break_points, integer(0))) {
-        for (iterator in seq_along(break_points)) {
-            modification_line <- raw_lines[break_points[iterator]]
-            modified_line <- gsub(target, replacement, modification_line)
-            raw_lines[break_points[iterator]] <- modified_line
-        }
+        raw_lines[break_points] <-  gsub(target, replacement, raw_lines[break_points])
         message(paste(
             "Found ", length(break_points), "Matches for target :", target))
     } else {
